@@ -48,7 +48,10 @@
 #define GID_NOGROUP 65534
 #endif
 
-
+#ifndef SA_RESTART
+/* ... and hope for the best */
+#define SA_RESTART 0
+#endif
 
 
 
@@ -312,6 +315,42 @@ static void reload_config (void)
    dict_init_databases (DictConfig);
 }
 
+static void xsigaddset (sigset_t *set, int signo)
+{
+   if (sigaddset (set, signo)){
+      log_error ("", "sigaddset(2) failed: %s\n", strerror (errno));
+   }
+}
+
+static void xsigprocmask (int how, const sigset_t *set, sigset_t *oset)
+{
+   if (sigprocmask (how, set, oset)){
+      log_error ("", "sigaddset(2) failed: %s\n", strerror (errno));
+   }
+}
+
+static void block_signals (void)
+{
+   sigset_t set;
+
+   sigemptyset (&set);
+   xsigaddset (&set, SIGALRM);
+   xsigaddset (&set, SIGCHLD);
+
+   xsigprocmask (SIG_BLOCK, &set, NULL);
+}
+
+static void unblock_signals (void)
+{
+   sigset_t set;
+
+   sigemptyset (&set);
+   xsigaddset (&set, SIGALRM);
+   xsigaddset (&set, SIGCHLD);
+
+   xsigprocmask (SIG_UNBLOCK, &set, NULL);
+}
+
 static void handler( int sig )
 {
    const char *name = NULL;
@@ -513,6 +552,7 @@ static const char *get_entry_info( dictDatabase *db, const char *entryName )
    dictWord *dw;
    lst_List list = lst_create();
    char     *pt, *buf;
+   size_t   len;
 
    if (
       0 >= dict_search (
@@ -542,7 +582,9 @@ static const char *get_entry_info( dictDatabase *db, const char *entryName )
    while (*pt == ' ' || *pt == '\t')
       ++pt;
 
-   pt[ strlen(pt) - 1 ] = '\0';
+   len = strlen(pt);
+   if (pt [len - 1] == '\n')
+      pt [len - 1] = '\0';
 
 #ifdef USE_PLUGIN
    call_dictdb_free (DictConfig->dbl);
@@ -1419,7 +1461,7 @@ static void pid_file_write ()
    }
 }
 
-void reopen_012 (void)
+static void reopen_012 (void)
 {
    int fd = open ("/dev/null", O_RDWR);
    if (fd == -1)
@@ -1446,6 +1488,8 @@ int main (int argc, char **argv, char **envp)
    int                forceStartup = 0;
    int                i;
 
+   int                errno_accept = 0;
+
    const char *       default_strategy_arg = "???";
 
    char *             new_strategy;
@@ -1697,7 +1741,7 @@ int main (int argc, char **argv, char **envp)
    dict_initsetproctitle(argc, argv, envp);
 
    if (inetd) {
-      dict_inetd(&argv, 0);
+      dict_inetd(0);
       exit(0);
    }
 
@@ -1712,10 +1756,15 @@ int main (int argc, char **argv, char **envp)
 
       if (flg_test(LOG_SERVER))
          log_info( ":I: %d accepting on %s\n", getpid(), daemon_service );
-      if ((childSocket = accept(masterSocket,
-				(struct sockaddr *)&csin, &alen)) < 0)
-      {
-	 switch (errno){
+
+/*unblock_signals ();*/
+      childSocket = accept (masterSocket,
+			    (struct sockaddr *)&csin, &alen);
+      errno_accept = errno;
+/*block_signals ();*/
+
+      if (childSocket < 0){
+	 switch (errno_accept){
 	 case EINTR:
 	    if (need_reload_config){
 	       reload_config ();
@@ -1737,13 +1786,13 @@ int main (int argc, char **argv, char **envp)
 	    continue;
 	 default:
 	    log_info (":E: can't accept: errno = %d: %s\n",
-		      errno, strerror (errno));
+		      errno_accept, strerror (errno_accept));
 	    err_fatal_errno (__func__, ":E: can't accept");
 	 }
       }
 
       if (_dict_daemon || dbg_test(DBG_NOFORK)) {
-	 dict_daemon(childSocket,&csin,&argv,0);
+	 dict_daemon(childSocket,&csin,0);
       } else {
 	 if (_dict_forks - _dict_reaps < _dict_daemon_limit_childs) {
 	    if (!start_daemon()) { /* child */
@@ -1755,16 +1804,14 @@ int main (int argc, char **argv, char **envp)
 		  alarm(_dict_daemon_limit_time);
 	       }
 
-	       dict_daemon (
-		  childSocket, &csin, &argv,
-		  databases_loaded ? 0 : 2);
+	       dict_daemon (childSocket, &csin, databases_loaded ? 0 : 2);
 
 	       exit(0);
 	    } else {		   /* parent */
 	       close(childSocket);
 	    }
 	 } else {
-	    dict_daemon(childSocket, &csin, &argv, 1);
+	    dict_daemon(childSocket, &csin, 1);
 	 }
       }
    }
