@@ -15,7 +15,7 @@
 #include <assert.h>
 #include <stddef.h>
 
-size_t mbrlen (const char *s, size_t n, mbstate_t *ps)
+size_t mbrlen__ (const char *s, size_t n, mbstate_t *ps)
 {
    int c;
 
@@ -25,7 +25,7 @@ size_t mbrlen (const char *s, size_t n, mbstate_t *ps)
 
    if (c == 0)
       return 0;
-   else if (MB_CUR_MAX == 1)
+   else if (MB_CUR_MAX__ == 1)
       return 1;
    else if (c <= 0x7F)
       return 1;
